@@ -15,10 +15,10 @@ foreach my $mod(qw(Text::Xslate Text::MicroTemplate)){
 my $n = shift(@ARGV) || 100;
 
 my $x = Text::Xslate->new(
-    string => "Hello, <?=  \$value + 1 ?> world!\n" x $n,
+    string => "Hello, <:=  \$value + 1 :> world!\n" x $n,
 );
 
-my $mt = build_mt(qq{Hello, <?= \$_[0]->{value} + 1 ?> world!\n} x $n);
+my $mt = build_mt(qq{Hello, <:= \$_[0]->{value} + 1 :> world!\n} x $n);
 
 my $subst_tmpl = qq{Hello, %value% world!\n} x $n;
 
